@@ -6,12 +6,24 @@ use warnings;
 use Log::ger;
 
 our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
-our $DATE = '2023-07-31'; # DATE
+our $DATE = '2023-08-02'; # DATE
 our $DIST = 'App-TrashUtils'; # DIST
-our $VERSION = '0.001'; # VERSION
+our $VERSION = '0.002'; # VERSION
 
 our %SPEC;
 
+sub _complete_trashed_filenames {
+    require Complete::Util;
+    require File::Trash::FreeDesktop;
+
+    my %args = @_;
+
+    my $trash = File::Trash::FreeDesktop->new;
+    my @ct = $trash->list_contents;
+
+    Complete::Util::complete_array_elem(array=>[map { my $filename = $_->{path}; $filename =~ s!.+/!!; $filename } @ct], word=>$args{word});
+}
+
 $SPEC{trash_list} = {
     v => 1.1,
     summary => 'List contents of trash directories',
@@ -34,6 +46,7 @@ being interpreted by the shell, e.g. to match files in the current directory.
 _
             schema => 'str*',
             pos => 0,
+            completion => \&_complete_trashed_filenames,
         },
     },
     examples => [
@@ -164,6 +177,7 @@ $SPEC{trash_rm} = {
             req => 1,
             pos => 0,
             slurpy => 1,
+            element_completion => \&_complete_trashed_filenames,
         },
         no_wildcard => {
             schema => 'true*',
@@ -237,6 +251,7 @@ $SPEC{trash_restore} = {
             req => 1,
             pos => 0,
             slurpy => 1,
+            element_completion => \&_complete_trashed_filenames,
         },
         no_wildcard => {
             schema => 'true*',
@@ -313,7 +328,7 @@ App::TrashUtils - Utilities related to desktop trash
 
 =head1 VERSION
 
-This document describes version 0.001 of App::TrashUtils (from Perl distribution App-TrashUtils), released on 2023-07-31.
+This document describes version 0.002 of App::TrashUtils (from Perl distribution App-TrashUtils), released on 2023-08-02.
 
 =head1 DESCRIPTION
 
